﻿''' <summary>
''' Gestiona la comunicació entre l'aplicació i la BBDD en l'àmbit de MISSATGES
''' </summary>
''' <remarks></remarks>
Public Class GestorBustiaBD
    Dim dc As CampusNetDataContext = New CampusNetDataContext()
    Private Property ara As Date = Now

    '....................................MÒDUL DE BÚSTIA DE MISSATGES.....................................................................

    ''' <summary>
    ''' Recupera la llista de missatges enviats per el usuari idUser
    ''' </summary>
    ''' <param name="idUser">id del usuari</param>
    ''' <returns>llista de missatges enviats</returns>
    ''' <remarks></remarks>
    Function RecuperaMissatgesEnviats(ByVal idUser As String) As System.Data.Linq.ISingleResult(Of RecuperaMissatgesEnviatsResult)
        Try

            Return dc.RecuperaMissatgesEnviats(idUser)

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorBustiaBD & ex.Message, vbExclamation)
            Return Nothing
        End Try
    End Function


    ''' <summary>
    ''' Recupera la llista de missatges rebuts per el usuari idUser
    ''' </summary>
    ''' <param name="idUser">id del usuari</param>
    ''' <returns>llista de missatges rebuts</returns>
    ''' <remarks></remarks>
    Function RecuperaMissatgesRebuts(ByVal idUser As String) As System.Data.Linq.ISingleResult(Of RecuperaMissatgesRebutsResult)
        Try
            Return dc.RecuperaMissatgesRebuts(idUser)

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorBustiaBD & ex.Message, vbExclamation)

            Return Nothing
        End Try
    End Function


    ''' <summary>
    ''' Recupera el missatge amb id=IdMissatge
    ''' </summary>
    ''' <param name="IdMissatge">id del missatge</param>
    ''' <returns>missatge</returns>
    ''' <remarks></remarks>
    Function RecuperaMissatge(ByVal IdMissatge As Integer) As System.Data.Linq.ISingleResult(Of RecuperaMissatgeResult)
        Try
            Return dc.RecuperaMissatge(IdMissatge)
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorBustiaBD & ex.Message, vbExclamation)

            Return Nothing

        End Try
    End Function

    ''' <summary>
    ''' Obté la data d'enviament d'un missatge
    ''' </summary>
    ''' <param name="idMissatge">idMissatge</param>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Function ObteDataEnviat(ByVal idMissatge As Integer, ByVal idUser As String) As DateTime
        Try
            Dim enviat As DateTime
            'recuperem el historial del missatge
            Dim queryHistorial As System.Data.Linq.ISingleResult(Of RecuperaHistorialResult) = dc.RecuperaHistorial(idMissatge, idUser)
            'cerquem la data de la acció="Enviat"
            For Each reg In queryHistorial
                If reg.Accio.Contains("Creat") Then
                    enviat = reg.Data
                End If
            Next
            Return enviat
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorBustiaBD & ex.Message, vbExclamation)

            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Marca un missatge com llegit en el moment en que es crida a la funció
    ''' </summary>
    ''' <param name="idMissatge">idMissatge</param>
    ''' <param name="idUser">idUser</param>
    ''' <remarks></remarks>
    Sub MarcaMissatgeComLlegit(ByVal idMissatge As Integer, ByVal idUser As String)
        Try
            dc.LlegeixMissatge(idMissatge, ara, idUser)

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorBustiaBD & ex.Message, vbExclamation)

        End Try
    End Sub

    ''' <summary>
    ''' Crea un nou missatge
    ''' </summary>
    ''' <param name="idRemitent">idRemitent</param>
    ''' <param name="idDestinatari">idDestinatari </param>
    ''' <param name="assumpte"> assumpte</param>
    ''' <param name="cos"> cos</param>
    ''' <remarks></remarks>
    Sub NouMissatge(ByVal idRemitent As String, ByVal idDestinatari As String, ByVal assumpte As String, ByVal cos As String)
        'Creem el nou missatge
        Try
            dc.NouMissatge(idRemitent, idDestinatari, assumpte, cos)
            'recuperem el id del missatge creat i creem un nou registre d'historial del missatge
            Dim query As System.Data.Linq.ISingleResult(Of RetornaUltimIDMissatgeResult) = dc.RetornaUltimIDMissatge
            For Each reg In query
                dc.HistorialNouMissatge(reg.Column1, ara, idRemitent)
            Next


        Catch ex As Exception

        End Try

    End Sub

    ''' <summary>
    ''' Recupera la llista d'accions associades a un missatge
    ''' </summary>
    ''' <param name="idMissatge">idMissatge</param>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Function RecuperaHistorial(ByVal idMissatge As Integer, ByVal idUser As String) As System.Data.Linq.ISingleResult(Of RecuperaHistorialResult)
        Try
            Return dc.RecuperaHistorial(idMissatge, idUser)
        Catch ex As Exception
            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Afegeix al historial del missatge el registre "Respost"
    ''' </summary>
    ''' <param name="idRemitent">idRemitent</param>
    ''' <param name="idMissatge">idMissatge</param>
    ''' <remarks></remarks>
    Sub ResponMissatge(ByVal idRemitent As String, ByVal idMissatge As Integer)

        Try
            dc.ResponMissatge(idMissatge, ara, idRemitent)
        Catch ex As Exception

        End Try

    End Sub
End Class
