﻿''' <summary>
''' Gestiona la comunicació entre l'aplicació i la BBDD en l'àmbit de events de calendari
''' </summary>
''' <remarks></remarks>
Public Class GestorCalendariBD
    Dim dc As CampusNetDataContext = New CampusNetDataContext()

    'INSERT

    ''' <summary>
    ''' Crea un nou event
    ''' </summary>
    ''' <param name="descripcio">descripcio</param>
    ''' <param name="perfil">perfil</param>
    ''' <param name="curs">curs</param>
    ''' <param name="data">data</param>
    ''' <returns>0 si correcte ,1 altrament</returns>
    ''' <remarks></remarks>
    Function NouEvent(ByVal descripcio As String, ByVal perfil As String, ByVal curs As String, ByVal data As Date)
        Dim resultat As Integer
        Try
            dc.NouEvent(descripcio, data, perfil, curs)
            resultat = 0
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCalendariBD_NouEvent & ex.Message, vbExclamation)
            resultat = 1
        End Try
        Return resultat
    End Function

    'UPDATE
    ''' <summary>
    '''  Actualitza les dades d'un event
    ''' </summary>
    ''' <param name="id"></param>
    ''' <param name="descripcio"></param>
    ''' <param name="perfil"></param>
    ''' <param name="curs"></param>
    ''' <param name="data"></param>
    ''' <returns>0 si correcte, 1 altrament</returns>
    ''' <remarks></remarks>
    Function ModificaEvent(ByVal id As String, ByVal descripcio As String, ByVal perfil As String, ByVal curs As String, ByVal data As Date)
        Dim resultat As Integer
        Try
            dc.ModificaEvent(id, descripcio, data, perfil, curs)
            resultat = 0
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCalendariBD_ModificaEvent & ex.Message)
            resultat = 1
        End Try
        Return resultat
    End Function

    ' SELECT

    ''' <summary>
    ''' Retorna la llista d'events 
    ''' </summary>
    ''' <returns>Llista si correcte, Nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaLlistaEvents() As System.Data.Linq.ISingleResult(Of RetornaLlistaEventsResult)
        Try
            Return dc.RetornaLlistaEvents()
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCalendariBD_RetornaLlistaEvents & ex.Message, vbExclamation)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Retorna la llista d'events associada a un curs
    ''' </summary>
    ''' <param name="idCurs">idCurs</param>
    ''' <returns>Llista si correcte, Nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaLlistaEvents(ByVal idCurs As Integer) As System.Data.Linq.ISingleResult(Of RetornaLlistaEventsCursResult)
        Try
            Return dc.RetornaLlistaEventsCurs(idCurs)
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCalendariBD_RetornaLlistaEvents & ex.Message, vbExclamation)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Retorna la llista de events associats a un usuari
    ''' </summary>
    ''' <param name="id"></param>
    ''' <returns>Llista si correcte, Nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaLlistaEventsUsuari(ByVal id As String) As Object
        Try
            If UsuariActiu.perfilUsuari.Contains("Alumne") Then
                Return dc.RetornaLlistaEventsUsuari(id)
            ElseIf UsuariActiu.perfilUsuari.Contains("Tutor") Then
                Return dc.RetornaLlistaEventsTutor(id)
            Else
                Return Nothing
            End If

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCalendariBD_RetornaLlistaEvents & ex.Message, vbExclamation)
            Return Nothing
        End Try
    End Function


    ''' <summary>
    ''' Retorna la llista d'events amb id=id
    ''' </summary>
    ''' <param name="idEvent">idEvent</param>
    ''' <returns>Llista si correcte, Nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaLlistaEventsId(ByVal idEvent As Integer) As System.Data.Linq.ISingleResult(Of RetornaLlistaEvents_IdResult)
        Try
            Return dc.RetornaLlistaEvents_Id(idEvent)
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCalendariBD_RetornaLlistaEvents & ex.Message, vbExclamation)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Retorna la llista d'events associats al usuari amb id=idUsuari,en el mes data.Month
    ''' </summary>
    ''' <param name="idUsuari">idUsuari</param>
    ''' <returns>Llista si correcte, Nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaLlistaEventsMes(ByVal idUsuari As String, ByVal data As Date) As Object
        Dim dataInici As Date = "01/" & data.Month.ToString & "/" & data.Year.ToString
        Dim dataFinal As Date = "01/" & data.AddMonths(1).Month.ToString & "/" & data.Year.ToString
        'si el mes resultant de la data final ès gener, hem de sumar un any
        If Month(dataFinal).Equals(1) Then dataFinal = dataFinal.AddYears(1)


        ' Retornem la llista de events dels cursos als que está assignat el alumne, dins el periode seleccionat

        Try
            If UsuariActiu.perfilUsuari.Contains("Alumne") Then
                Return dc.RetornaLlistaEventsMes(UsuariActiu.idUsuari, dataInici, dataFinal)
            ElseIf UsuariActiu.perfilUsuari.Contains("Tutor") Then
                Return dc.RetornaLlistaEventsMesTutor(UsuariActiu.idUsuari, dataInici, dataFinal)
            Else
                Return Nothing
            End If

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCalendariBD_RetornaLlistaEvents & ex.Message, vbExclamation)
            Return Nothing
        End Try
    End Function



    'DELETE

    ''' <summary>
    ''' Elimina l'event amb Id=id
    ''' </summary>
    ''' <param name="id"></param>
    ''' <remarks></remarks>
    Sub EliminaEvent(ByVal id As String)
        Try
            dc.EliminaEvent(id)
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCalendariBD_EliminaEvent & ex.Message, vbExclamation)
        End Try
    End Sub
End Class
