﻿''' <summary>
''' Gestiona la comunicació entre l'aplicació i la BBDD en l'àmbit de CURSOS
''' </summary>
''' <remarks></remarks>
Public Class GestorCursosBD
    Dim dc As CampusNetDataContext = New CampusNetDataContext()

    'INSERT

    ''' <summary>
    ''' Inserta un nou curs a la BBDD
    ''' </summary>
    ''' <param name="nom"></param>
    ''' <param name="descripcio"></param>
    ''' <param name="tutor"></param>
    ''' <param name="inici"></param>
    ''' <param name="fi"></param>
    ''' <returns>0 si correcte ,1 altrament</returns>
    ''' <remarks></remarks>
    Function NouCurs(ByVal id As String, ByVal nom As String, ByVal descripcio As String, ByVal tutor As String _
                     , ByVal inici As Date, ByVal fi As Date) As Integer
        Dim resultat As Integer

        Try
            dc.NouCurs(id, nom, descripcio, tutor, inici, fi)
            resultat = 0
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_NouCurs & ex.Message)
            resultat = 1
        End Try
        Return resultat
    End Function

    ''' <summary>
    ''' Crea un nou contingut
    ''' </summary>
    ''' <param name="nom"></param>
    ''' <param name="descripcio"></param>
    ''' <param name="tipus"></param>
    ''' <param name="ruta"></param>
    ''' <returns>0 si correcte, 1 altrament</returns>
    ''' <remarks></remarks>
    Function NouContingut(ByVal nom As String, ByVal descripcio As String, ByVal tipus As String, ByVal ruta As String) As Integer
        Dim resultat As Integer

        Try
            dc.NouContingut(nom, descripcio, ruta, tipus)
            resultat = 0
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_NouContingut & ex.Message)
            resultat = 1
        End Try
        Return resultat
    End Function

    ''' <summary>
    ''' Crea un nou recurs
    ''' </summary>
    ''' <param name="nom"></param>
    ''' <param name="descripcio"></param>
    ''' <param name="tipus"></param>
    ''' <param name="ruta"></param>
    ''' <returns>0 si correcte, 1 altrament</returns>
    ''' <remarks></remarks>
    Function NouRecurs(ByVal nom As String, ByVal descripcio As String, ByVal tipus As String, ByVal ruta As String) As Integer
        Dim resultat As Integer

        Try
            dc.NouRecurs(nom, descripcio, ruta, tipus)
            resultat = 0
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_NouRecurs & ex.Message)
            resultat = 1
        End Try
        Return resultat
    End Function

    ''' <summary>
    ''' Crea un nou test
    ''' </summary>
    ''' <param name="nom"></param>
    ''' <param name="dataAlta"></param>
    ''' <returns>0 si correcte, 1 altrament</returns>
    ''' <remarks></remarks>
    Function NouTest(ByVal nom As String, ByVal dataAlta As DateTime) As Integer
        Dim resultat As Integer

        Try
            dc.NouTest(nom, dataAlta)
            resultat = 0
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_NouTest & ex.Message)
            resultat = 1
        End Try
        Return resultat
    End Function

    ''' <summary>
    ''' Crea una nova pregunta i l'afegeix a la llista de preguntes del test
    ''' </summary>
    ''' <param name="idTest"></param>
    ''' <param name="textPregunta"></param>
    ''' <param name="correcte"></param>
    ''' <param name="incorrecte"></param>
    ''' <returns>0 si correcte, 1 altrament</returns>
    ''' <remarks></remarks>
    Function NovaPregunta(ByVal idTest As Integer, ByVal textPregunta As String, ByVal correcte As Double, ByVal incorrecte As Double) As Integer
        Dim resultat As Integer

        Try
            'creem la nova pregunta
            dc.NovaPregunta(textPregunta, correcte, incorrecte)
            'recuperem l'id de la pregunta creada
            Dim nouId As Integer
            For Each pregunta In dc.RetornaIdUltimaPregunta()
                nouId = pregunta.Column1
            Next
            'afegim la pregunta a la llista de preguntes del test
            dc.NovaLlistaPregunta(idTest, nouId)

            resultat = 0
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_NouTest & ex.Message)
            resultat = 1
        End Try
        Return resultat
    End Function

    ''' <summary>
    ''' Crea una nova resposta i l'afegeix a la llista de respostes de la pregunta
    ''' </summary>
    ''' <param name="idPregunta"></param>
    ''' <param name="textResposta"></param>
    ''' <param name="esCorrecte"></param>
    ''' <returns>0 si correcte, 1 altrament</returns>
    ''' <remarks></remarks>
    Function NovaResposta(ByVal idPregunta As Integer, ByVal textResposta As String, ByVal esCorrecte As Integer) As Integer
        Dim resultat As Integer

        Try
            'creem la nova resposta
            dc.NovaResposta(textResposta, esCorrecte)
            'recuperem l'id de la resposta creada
            Dim nouId As Integer
            For Each resposta In dc.RetornaIdUltimaResposta()
                nouId = CInt(resposta.Column1)
            Next
            'afegim la resposta a la llista de respostes de la pregunta
            dc.NovaLlistaResposta(idPregunta, nouId)

            resultat = 0
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_NovaResposta & ex.Message)
            resultat = 1
        End Try
        Return resultat
    End Function

    ''' <summary>
    ''' Assigna el alumne idAlumne al curs idCurs
    ''' </summary>
    ''' <param name="idAlumne"></param>
    ''' <param name="idCurs"></param>
    ''' <returns>0 si correcte ,1 altrament</returns>
    ''' <remarks></remarks>
    Function AssignaAlumne(ByVal idAlumne As String, ByVal idCurs As String)
        Dim resultat As Integer
        ' comprovem que l'alumne no sigui ja assignat
        Try
            For Each alumne In dc.RetornaLlistaAlumnesCurs(idCurs)
                If idAlumne.Contains(alumne.Alumne) Then
                    MsgBox(Resources.Missatges.Info_GestorCursosBD_AssignaAlumne_Alumne_ja_existeix, vbInformation)
                    resultat = 1
                    Return resultat ' si es així, sortim amb resultat error
                End If
            Next
            Try
                dc.AssignaAlumne_a_Curs(idAlumne, idCurs)
                resultat = 0
            Catch ex As Exception
                MsgBox(Resources.Missatges.Error_GestorCursosBD_AssignaAlumne & ex.Message, vbExclamation)
                resultat = 1
            End Try
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_AssignaAlumne & ex.Message, vbExclamation)
            resultat = 1
        End Try

        
        Return resultat

    End Function


    ''' <summary>
    ''' Assigna el contingut idContingut al curs idCurs
    ''' </summary>
    ''' <param name="idContingut"></param>
    ''' <param name="idCurs"></param>
    ''' <returns>0 si correcte ,1 altrament</returns>
    ''' <remarks></remarks>
    Function AssignaContingut(ByVal idContingut As String, ByVal idCurs As String)
        Dim resultat As Integer
        ' comprovem que el contingut no sigui ja assignat
        Try
            For Each contingut In dc.RetornaLlistaContingutsCurs(idCurs)
                If idContingut.Contains(contingut.Contingut) Then
                    MsgBox(Resources.Missatges.Info_GestorCursosBD_AssignaContingut_Contingut_ja_existeix, vbInformation)
                    resultat = 1
                    Return resultat ' si es així, sortim amb resultat error
                End If
            Next
            Try
                dc.AssignaContingut(idContingut, idCurs)
                resultat = 0
            Catch ex As Exception
                MsgBox(Resources.Missatges.Error_GestorCursosBD_AssignaContingut & ex.Message, vbExclamation)
                resultat = 1
            End Try
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_AssignaContingut & ex.Message, vbExclamation)
            resultat = 1
        End Try


        Return resultat

    End Function


    ''' <summary>
    ''' Assigna el recurs idRecurs al curs idCurs
    ''' </summary>
    ''' <param name="idRecurs"></param>
    ''' <param name="idCurs"></param>
    ''' <returns>0 si correcte ,1 altrament</returns>
    ''' <remarks></remarks>
    Function AssignaRecurs(ByVal idRecurs As String, ByVal idCurs As String)
        Dim resultat As Integer
        ' comprovem que el recurs no sigui ja assignat
        Try
            For Each recurs In dc.RetornaLlistaRecursosCurs(idCurs)
                If idRecurs.Contains(recurs.Recurs) Then
                    MsgBox(Resources.Missatges.Info_GestorCursosBD_AssignaContingut_Contingut_ja_existeix, vbInformation)
                    resultat = 1
                    Return resultat ' si es així, sortim amb resultat error
                End If
            Next
            Try
                dc.AssignaRecurs(idRecurs, idCurs)
                resultat = 0
            Catch ex As Exception
                MsgBox(Resources.Missatges.Error_GestorCursosBD_AssignaContingut & ex.Message, vbExclamation)
                resultat = 1
            End Try
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_AssignaContingut & ex.Message, vbExclamation)
            resultat = 1
        End Try


        Return resultat

    End Function

    ''' <summary>
    '''  Assigna el test idTest al curs idCurs
    ''' </summary>
    ''' <param name="idTest"></param>
    ''' <param name="idCurs"></param>
    ''' <returns>0 si correcte ,1 altrament</returns>
    ''' <remarks></remarks>
    Function AssignaTest(ByVal idTest As String, ByVal idCurs As String)
        Dim resultat As Integer
        ' comprovem que el test no sigui ja assignat
        Try
            For Each test In dc.RetornaLlistaTestCurs(idCurs)
                If idTest.Contains(test.Test) Then
                    MsgBox(Resources.Missatges.Info_GestorCursosBD_AssignaTest_Test_ja_existeix, vbInformation)
                    resultat = 1
                    Return resultat ' si es així, sortim amb resultat error
                End If
            Next
            Try
                dc.AssignaTest_a_curs(idTest, idCurs)
                resultat = 0
            Catch ex As Exception
                MsgBox(Resources.Missatges.Error_GestorCursosBD_AssignaTest & ex.Message, vbExclamation)
                resultat = 1
            End Try
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_AssignaTest & ex.Message, vbExclamation)
            resultat = 1
        End Try


        Return resultat

    End Function


    ''' <summary>
    ''' Afegeix una resposta escollida a la llista de respostes escollides de la  accio de fer un test
    ''' </summary>
    ''' <param name="idResultatTest">id de la llista de resultat del test realitzat</param>
    ''' <param name="idResposta">id de la resposta escollida</param>
    ''' <remarks></remarks>
    Sub AfegirRespostaEscollida(ByVal idResultatTest As Integer, ByVal idResposta As Integer, ByVal punts As Double)

        Try
            dc.NovaRespostaEscollida(idResultatTest, idResposta, punts)

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_AfegirRespostaEscollida & ex.Message, vbExclamation)

        End Try
    End Sub

    ''' <summary>
    ''' Afegeix el resultat de la realització d'un test amb id=idtest
    ''' </summary>
    ''' <param name="idtest"></param>
    ''' <param name="idCurs"></param>
    ''' <param name="idAlumne"></param>
    ''' <param name="realitzat"></param>
    ''' <param name="puntuacio"></param>
    ''' <remarks></remarks>
    Sub AfegirResultatTest(ByVal idtest As Integer, ByVal idCurs As String, ByVal idAlumne As String, ByVal realitzat As Date, ByVal puntuacio As Double)
        Try
            dc.NouResultatTest(idtest, idCurs, idAlumne, realitzat, puntuacio)

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_AfegirResultatTest & ex.Message, vbExclamation)

        End Try
    End Sub

    ''' <summary>
    ''' Assigna la nota del alumne en el curs
    ''' </summary>
    ''' <param name="idCurs"></param>
    ''' <param name="idAlumne"></param>
    ''' <param name="nota"></param>
    ''' <returns>0 si correcte , 1 altrament</returns>
    ''' <remarks></remarks>
    Function AssignaNota(ByVal idCurs As String, ByVal idAlumne As String, ByVal nota As String) As Integer
        Dim resultat As Integer
        Try
            dc.AssignaNota(idAlumne, idCurs, nota)
            resultat = 0
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_AssignaNota & ex.Message, vbExclamation)

            resultat = 1
        End Try
        Return resultat
    End Function

    'UPDATE

    ''' <summary>
    '''  Actualitza les dades modificades d'un curs
    ''' </summary>
    ''' <param name="id"></param>
    ''' <param name="nom"></param>
    ''' <param name="descripcio"></param>
    ''' <param name="tutor"></param>
    ''' <param name="inici"></param>
    ''' <param name="fi"></param>
    ''' <returns>0 si correcte ,1 altrament</returns>
    ''' <remarks></remarks>
    Function ModificaCurs(ByVal id As String, ByVal nom As String, ByVal descripcio As String, ByVal tutor As String _
                   , ByVal inici As Date, ByVal fi As Date) As Integer
        Dim resultat As Integer

        Try
            dc.ModificaCurs(id, nom, descripcio, tutor, inici, fi)
            resultat = 0
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_ModificaCurs & ex.Message)
            resultat = 1
        End Try
        Return resultat
    End Function

    ''' <summary>
    ''' Actualitza les dades d'un contingut
    ''' </summary>
    ''' <param name="nom"></param>
    ''' <param name="descripcio"></param>
    ''' <param name="tipus"></param>
    ''' <param name="ruta"></param>
    ''' <returns>0 si correcte ,1 altrament</returns>
    ''' <remarks></remarks>
    Function ModificaContingut(ByVal Id As Integer, ByVal nom As String, ByVal descripcio As String, ByVal tipus As String, ByVal ruta As String) As Integer
        Dim resultat As Integer

        Try
            dc.ModificaContingut(Id, nom, descripcio, ruta, tipus)
            resultat = 0
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_ModificaContingut & ex.Message)
            resultat = 1
        End Try
        Return resultat
    End Function

    ''' <summary>
    ''' Actualitza les dades d'un recurs
    ''' </summary>
    ''' <param name="nom"></param>
    ''' <param name="descripcio"></param>
    ''' <param name="tipus"></param>
    ''' <param name="ruta"></param>
    ''' <returns>0 si correcte ,1 altrament</returns>
    ''' <remarks></remarks>
    Function ModificaRecurs(ByVal Id As Integer, ByVal nom As String, ByVal descripcio As String, ByVal tipus As String, ByVal ruta As String) As Integer
        Dim resultat As Integer

        Try
            dc.ModificaRecurs(Id, nom, descripcio, ruta, tipus)
            resultat = 0
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_ModificaRecurs & ex.Message)
            resultat = 1
        End Try
        Return resultat
    End Function

    ''' <summary>
    ''' Actualitza les dades d'un test
    ''' </summary>
    ''' <param name="nom"></param>
    ''' <param name="dataAlta"></param>
    ''' <returns>0 si correcte, 1 altrament</returns>
    ''' <remarks></remarks>
    Function ModificaTest(ByVal idTest As Integer, ByVal nom As String, ByVal dataAlta As DateTime) As Integer
        Dim resultat As Integer

        Try
            dc.ModificaTest(idTest, nom, dataAlta)
            resultat = 0
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_ModificaTest & ex.Message)
            resultat = 1
        End Try
        Return resultat
    End Function

    ''' <summary>
    ''' Actualitza les dades d'una pregunta
    ''' </summary>
    ''' <param name="idPregunta"></param>
    ''' <param name="textPregunta"></param>
    ''' <param name="correcte"></param>
    ''' <param name="incorrecte"></param>
    ''' <returns>0 si correcte, 1 altrament</returns>
    ''' <remarks></remarks>
    Function ModificaPregunta(ByVal idPregunta As Integer, ByVal textPregunta As String, ByVal correcte As Double, ByVal incorrecte As Double) As Integer
        Dim resultat As Integer

        Try
            dc.ModificaPregunta(idPregunta, textPregunta, correcte, incorrecte)
            resultat = 0
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_ModificaPregunta & ex.Message)
            resultat = 1
        End Try
        Return resultat
    End Function

    ''' <summary>
    ''' Actualitza les dades d'una resposta
    ''' </summary>
    ''' <param name="idResposta"></param>
    ''' <param name="textResposta"></param>
    ''' <param name="esCorrecte"></param>
    ''' <returns>0 si correcte, 1 altrament</returns>
    ''' <remarks></remarks>
    Function ModificaResposta(ByVal idResposta As Integer, ByVal textResposta As String, ByVal esCorrecte As Integer) As Integer
        Dim resultat As Integer

        Try
            dc.ModificaResposta(idResposta, textResposta, esCorrecte)
            resultat = 0
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_ModificaResposta & ex.Message)
            resultat = 1
        End Try
        Return resultat
    End Function

    'DELETE

    ''' <summary>
    '''  Elimina el curs amb id=id
    ''' </summary>
    ''' <param name="id">id</param>
    ''' <remarks></remarks>
    Sub EliminaCurs(ByVal id As String)
        Try
            dc.EliminaCurs(id)
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_EliminaCurs & ex.Message, vbExclamation)
        End Try

    End Sub

    ''' <summary>
    '''  Elimina el contingut amb id=id
    ''' </summary>
    ''' <param name="id">id</param>
    ''' <remarks></remarks>
    Sub EliminaContingut(ByVal id As String)
        Try
            dc.EliminaContingut(id)
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_EliminaContingut & ex.Message, vbExclamation)
        End Try

    End Sub

    ''' <summary>
    '''  Elimina el recurs amb id=id
    ''' </summary>
    ''' <param name="id">id</param>
    ''' <remarks></remarks>
    Sub EliminaRecurs(ByVal id As String)
        Try
            dc.EliminaRecurs(id)
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_EliminaRecurs & ex.Message, vbExclamation)
        End Try

    End Sub

    ''' <summary>
    '''  Elimina el test amb id=id
    ''' </summary>
    ''' <param name="id">id</param>
    ''' <remarks></remarks>
    Sub EliminaTest(ByVal id As String)
        Try
            dc.EliminaTest(id)
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_EliminaTest & ex.Message, vbExclamation)
        End Try

    End Sub


    ''' <summary>
    ''' Desassigna els vincles entre un alumne i un curs
    ''' </summary>
    ''' <param name="idAlumne"></param>
    ''' <param name="idCurs"></param>
    ''' <remarks></remarks>
    Sub EliminaAssignacioAlumne(ByVal idAlumne As String, ByVal idCurs As String)
        Try
            dc.EsborraAssignacioAlumne_a_curs(idCurs, idAlumne)

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_EliminaAssignacioAlumne & ex.Message, vbExclamation)
        End Try

    End Sub

    ''' <summary>
    ''' Desassigna els vincles entre un contingut i un curs
    ''' </summary>
    ''' <param name="idContingut"></param>
    ''' <param name="idCurs"></param>
    ''' <remarks></remarks>
    Sub EliminaAssignacioContingut(ByVal idContingut As String, ByVal idCurs As String)
        Try
            dc.EsborraAssignacioContingut(idContingut, idCurs)

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_EliminaAssignacioContingut & ex.Message, vbExclamation)
        End Try

    End Sub

    ''' <summary>
    ''' Desassigna els vincles entre un recurs i un curs
    ''' </summary>
    ''' <param name="idRecurs"></param>
    ''' <param name="idCurs"></param>
    ''' <remarks></remarks>
    Sub EliminaAssignacioRecurs(ByVal idRecurs As String, ByVal idCurs As String)
        Try
            dc.EsborraAssignacioRecurs(idRecurs, idCurs)

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_EliminaAssignacioContingut & ex.Message, vbExclamation)
        End Try

    End Sub

    ''' <summary>
    ''' Desassigna els vincles entre un test i un curs
    ''' </summary>
    ''' <param name="idTest"></param>
    ''' <param name="idCurs"></param>
    ''' <remarks></remarks>
    Sub EliminaAssignacioTest(ByVal idTest As Integer, ByVal idCurs As String)
        Try
            dc.EsborraAssignacioTest(idCurs, idTest)

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_EliminaAssignacioTest & ex.Message, vbExclamation)
        End Try

    End Sub

    ''' <summary>
    ''' Elimina una resposta de test
    ''' </summary>
    ''' <param name="id"></param>
    ''' <remarks></remarks>
    Sub EliminaResposta(ByVal id As String)
        Try
            dc.EliminaResposta(id)
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_EliminaResposta & ex.Message, vbExclamation)
        End Try

    End Sub

    ''' <summary>
    ''' Elimina la pregunta amb id=id, y la seva llista de respostes associades
    ''' </summary>
    ''' <param name="id"></param>
    ''' <remarks></remarks>
    Sub EliminaPregunta(ByVal id As String)
        Try
            'primer eliminem les respostes a la pregunta
            For Each resposta In dc.RetornaLlistaRespostesPregunta(id)
                dc.EliminaResposta(resposta.Resposta)
            Next
            'ara eliminem la pregunta
            dc.EliminaPregunta(id)
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_EliminaPregunta & ex.Message, vbExclamation)
        End Try

    End Sub

    'SELECT

    ''' <summary>
    ''' Retorna el curs amb id=id
    ''' </summary>
    ''' <param name="id">id</param>
    ''' <returns>el curs amb id=id</returns>
    ''' <remarks></remarks>
    Function RetornaCurs(ByVal id As String) As System.Data.Linq.ISingleResult(Of RetornaCursResult)

        Try
            Return dc.RetornaCurs(id)

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaCurs & ex.Message)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Retorna el contingut amb id=id
    ''' </summary>
    ''' <param name="id">id</param>
    ''' <returns>el curs amb id=id</returns>
    ''' <remarks></remarks>
    Function RetornaContingut(ByVal id As String) As System.Data.Linq.ISingleResult(Of RetornaContingutResult)

        Try
            Return dc.RetornaContingut(id)

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaContingut & ex.Message)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Retorna el recurs amb id=id
    ''' </summary>
    ''' <param name="id">id</param>
    ''' <returns>el recurs amb id=id</returns>
    ''' <remarks></remarks>
    Function RetornaRecurs(ByVal id As String) As System.Data.Linq.ISingleResult(Of RetornaRecursResult)

        Try
            Return dc.RetornaRecurs(id)

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaRecurs & ex.Message)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    '''  retorna la llista de cursos
    ''' </summary>
    ''' <returns>Llista si Ok,nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaLlistaCursos() As System.Data.Linq.ISingleResult(Of RetornaLlistaCursosResult)
        Try
            Return dc.RetornaLlistaCursos()


        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaCurs & ex.Message)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    '''  retorna la llista de cursos del alumne amb idAlumne
    ''' </summary>
    ''' <param name="idAlumne"></param>
    ''' <returns>Llista si Ok,nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaLlistaCursosAlumne(ByVal idAlumne As String) As System.Data.Linq.ISingleResult(Of RetornaLlistaCursosAlumneResult)
        Try
            Return dc.RetornaLlistaCursosAlumne(idAlumne)


        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaCurs & ex.Message)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    '''  retorna la llista de test
    ''' </summary>
    ''' <returns>Llista si Ok,nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaLlistaTest() As System.Data.Linq.ISingleResult(Of RetornaLlistaTestResult)
        Try
            Return dc.RetornaLlistaTest()


        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaTest & ex.Message)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Retorna la llista de test del curs
    ''' </summary>
    ''' <param name="idCurs"></param>
    ''' <returns>Llista si OK, nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaLlistaTestCurs(ByVal idCurs) As System.Data.Linq.ISingleResult(Of RetornaLlistaTestCursResult)
        Try
            Return dc.RetornaLlistaTestCurs(idCurs)
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaLlistaTestCurs & ex.Message)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Retorna el test amb id=id
    ''' </summary>
    ''' <param name="id">id</param>
    ''' <returns>el test amb id=id si correcte, nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaTestId(ByVal id As String) As System.Data.Linq.ISingleResult(Of RetornaTest_IdResult)

        Try
            Return dc.RetornaTest_Id(id)

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaTest & ex.Message)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    '''  retorna la llista de cursos amb tutor principal=idTutor
    ''' </summary>
    ''' <returns>Llista si Ok,nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaLlistaCursosTutor(ByVal idTutor As String) As System.Data.Linq.ISingleResult(Of RetornaLlistaCursosTutorResult)
        Try
            Return dc.RetornaLlistaCursosTutor(idTutor)


        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaCurs & ex.Message)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Retorna la llista d'alumnes del curs
    ''' </summary>
    ''' <param name="idCurs"></param>
    ''' <returns>Llista si OK, nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaLlistaAlumnesCurs(ByVal idCurs) As System.Data.Linq.ISingleResult(Of RetornaLlistaAlumnesCursResult)
        Try
            Return dc.RetornaLlistaAlumnesCurs(idCurs)
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaLlistaAlumnesCurs & ex.Message)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Retorna la llista de continguts del curs
    ''' </summary>
    ''' <param name="idCurs"></param>
    ''' <returns>Llista si OK, nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaLlistaContingutsCurs(ByVal idCurs) As System.Data.Linq.ISingleResult(Of RetornaLlistaContingutsCursResult)
        Try
            Return dc.RetornaLlistaContingutsCurs(idCurs)
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaLlistaContingutsCurs & ex.Message)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Retorna la llista de continguts 
    ''' </summary>
    ''' <returns>Llista si OK, nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaLlistaContinguts() As System.Data.Linq.ISingleResult(Of RetornaLlistaContingutsResult)
        Try
            Return dc.RetornaLlistaContinguts()
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaLlistaContingutsCurs & ex.Message)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Retorna la llista de recursos 
    ''' </summary>
    ''' <returns>Llista si OK, nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaLlistaRecursos() As System.Data.Linq.ISingleResult(Of RetornaLlistaRecursosResult)
        Try
            Return dc.RetornaLlistaRecursos()
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaLlistaContingutsCurs & ex.Message)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Retorna la llista de recursos del curs
    ''' </summary>
    ''' <param name="idCurs"></param>
    ''' <returns>Llista si OK, nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaLlistaRecursosCurs(ByVal idCurs) As System.Data.Linq.ISingleResult(Of RetornaLlistaRecursosCursResult)
        Try
            Return dc.RetornaLlistaRecursosCurs(idCurs)
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaLlistaRecursosCurs & ex.Message)
            Return Nothing
        End Try
    End Function


    ''' <summary>
    ''' Retorna la llista de preguntes del test
    ''' </summary>
    ''' <param name="idTest"></param>
    ''' <returns>Llista si OK, nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaLlistaPreguntesTest(ByVal idTest As Integer) As System.Data.Linq.ISingleResult(Of RetornaLlistaPreguntesTestResult)
        Try
            Return dc.RetornaLlistaPreguntesTest(idTest)
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaLlistaPreguntesTest & ex.Message)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Retorna la pregunta amb id=id
    ''' </summary>
    ''' <param name="id">id</param>
    ''' <returns>pregunta amb id=id si correcte, nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaPreguntaId(ByVal id As String) As System.Data.Linq.ISingleResult(Of RetornaPreguntaIdResult)

        Try
            Return dc.RetornaPreguntaId(id)

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaPreguntaId & ex.Message)
            Return Nothing
        End Try
    End Function


    ''' <summary>
    ''' Retorna la llista de respostes a la pregunta
    ''' </summary>
    ''' <param name="idPregunta"></param>
    ''' <returns>Llista si OK, nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaLlistaRespostesPregunta(ByVal idPregunta) As System.Data.Linq.ISingleResult(Of RetornaLlistaRespostesPreguntaResult)
        Try
            Return dc.RetornaLlistaRespostesPregunta(idPregunta)
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaLlistaRespostesPregunta & ex.Message)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Retorna la resposta amb id=id
    ''' </summary>
    ''' <param name="id">id</param>
    ''' <returns>resposta amb id=id si correcte, nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaRespostaId(ByVal id As String) As System.Data.Linq.ISingleResult(Of RetornaRespostaIdResult)

        Try
            Return dc.RetornaRespostaId(id)

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaRespostaId & ex.Message)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Retorna el ultim valor del camp Id de la taula ResultatTest
    ''' </summary>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Function retornaUltimIdResultatTest() As System.Data.Linq.ISingleResult(Of RetornaUltimIDResultatTestResult)
        Try
            Return dc.retornaUltimIDResultatTest

        Catch ex As Exception
            Return Nothing
        End Try
    End Function


    ''' <summary>
    ''' Retorna els resultats complerts d'un test qualsevol
    ''' </summary>
    ''' <param name="idResultatTest"></param>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Function obtenirResultatsTestRealitzat(ByVal idResultatTest As Integer) As Object
        Try
            Return dc.ObtenirResultatsTest(idResultatTest)
        Catch ex As Exception
            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Retorna el valor de resposta correcte
    ''' </summary>
    ''' <param name="idResposta"></param>
    ''' <returns>valor si correcte,nothing altrament</returns>
    ''' <remarks></remarks>
    Function ValorRespostaCorrecte(ByVal idResposta As Integer) As Double
        Dim resultat As Double = Nothing
        Try

            For Each resposta In dc.ObtePreguntaDeResposta(idResposta)
                resultat = resposta.PuntsRespostaCorrecte
            Next

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_ValorResposta & ex.Message, vbExclamation)
        End Try
        Return resultat
    End Function

    ''' <summary>
    ''' Retorna el valor de resposta incorrecte
    ''' </summary>
    ''' <param name="idResposta"></param>
    ''' <returns>valor si correcte,nothing altrament</returns>
    ''' <remarks></remarks>
    Function ValorRespostaIncorrecte(ByVal idResposta As Integer) As Double
        Dim resultat As Double = Nothing
        Try

            For Each resposta In dc.ObtePreguntaDeResposta(idResposta)
                resultat = resposta.PuntsRespostaIncorrecte
            Next

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_ValorResposta & ex.Message, vbExclamation)
        End Try
        Return resultat
    End Function

    ''' <summary>
    ''' Comprova si l'alumne ha realitzat el test
    ''' </summary>
    ''' <param name="idTest"></param>
    ''' <param name="idAlumne"></param>
    ''' <returns>true si realitzat, false altrament</returns>
    ''' <remarks></remarks>
    Function ComprovaTestRealitzat(ByVal idTest As Integer, ByVal idAlumne As String) As Boolean
        Dim resultat As Boolean = False
        Try
            For Each testRealitzat In dc.RetornaLlistaTestRealitzats()
                If idTest = testRealitzat.Test And idAlumne.Contains(testRealitzat.Alumne) Then resultat = True

            Next
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_ComprovaTestRealitzat & ex.Message, vbExclamation)
        End Try

        Return resultat
    End Function

    ''' <summary>
    ''' Retorna la llista de test realitzats per un alumne
    ''' </summary>
    ''' <param name="idAlumne"></param>
    ''' <returns>llista si correcte, nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaLlistaTestRealitzatsAlumne(ByVal idAlumne As String) As System.Data.Linq.ISingleResult(Of RetornaLlistaTestRealitzatsAlumneResult)
        Try
            Return dc.RetornaLlistaTestRealitzatsAlumne(idAlumne)
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_ComprovaTestRealitzat & ex.Message, vbExclamation)
            Return Nothing

        End Try
    End Function

    ''' <summary>
    ''' Retorna el nom d'un test
    ''' </summary>
    ''' <param name="idTest"></param>
    ''' <returns>nom si correcte, nothing altrament</returns>
    ''' <remarks></remarks>
    Function RetornaNomTest(ByVal idTest As Integer) As String
        Dim nom As String = Nothing
        Try
            For Each Test In dc.RetornaTest_Id(idTest)
                nom = Test.Nom
            Next
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaNomTest & ex.Message, vbExclamation)

        End Try
        Return nom
    End Function

    ''' <summary>
    ''' Retorna la llista de les respostes escollides per un alumne a un test
    ''' </summary>
    ''' <param name="idAlumne"></param>
    ''' <param name="idTest"></param>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Function RetornaLlistaRespostesEscollides(ByVal idAlumne As String, ByVal idTest As Integer) As System.Data.Linq.ISingleResult(Of RetornaLlistaRespostesEscollidesResult)
        Try
            Return dc.RetornaLlistaRespostesEscollides(idTest, idAlumne)
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaLlistaRespostesEscollides & ex.Message, vbExclamation)
            Return Nothing
        End Try
    End Function

    ''' <summary>
    ''' Retorna la nota del alumne en el curs
    ''' </summary>
    ''' <param name="idAlumne"></param>
    ''' <param name="idCurs"></param>
    ''' <returns>nota</returns>
    ''' <remarks></remarks>
    Function RetornaNotaAlumne(ByVal idAlumne As String, ByVal idCurs As String) As String
        Dim nota As String = Nothing
        Try
            For Each reg In dc.RetornaLlistaAlumnesCurs(idCurs)
                If reg.Alumne.Contains(idAlumne) Then
                    nota = reg.Nota
                End If

            Next
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaNotaAlumne & ex.Message, vbExclamation)

        End Try
        Return nota
    End Function


    ''' <summary>
    ''' Retorna la llista de cursos amb nom similar a nomCurs
    ''' </summary>
    ''' <param name="nomCurs"></param>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Function RetornaCursosNom(ByVal nomCurs As String) As IEnumerable
        Dim consulta As IEnumerable
        Try
            consulta = From cursCercat In dc.Curs
                    Where cursCercat.Nom.Contains(nomCurs)
                    Select cursCercat
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaCurs & ex.Message)

            consulta = Nothing
        End Try
        Return consulta
    End Function


    ''' <summary>
    ''' Retorna la llista de test amb nom similar a nomCurs
    ''' </summary>
    ''' <param name="nomTest"></param>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Function RetornaTestNom(ByVal nomTest As String) As IEnumerable
        Dim consulta As IEnumerable
        Try
            consulta = From testCercat In dc.Tests
                       Where testCercat.Nom.Contains(nomTest)
                       Select testCercat
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaTest & ex.Message)

            consulta = Nothing
        End Try
        Return consulta
    End Function
    ''' <summary>
    ''' Retorna la llista de contingut amb nom similar a nomContingut
    ''' </summary>
    ''' <param name="nomContingut"></param>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Function RetornaContingutNom(ByVal nomContingut As String) As IEnumerable
        Dim consulta As IEnumerable
        Try
            consulta = From contingutCercat In dc.Continguts
                       Where contingutCercat.Nom.Contains(nomContingut)
                       Select contingutCercat
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaContingut & ex.Message)

            consulta = Nothing
        End Try
        Return consulta
    End Function
    ''' <summary>
    ''' Retorna la llista de recursos amb nom similar a nomRecurs
    ''' </summary>
    ''' <param name="nomRecurs"></param>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Function RetornaRecursNom(ByVal nomRecurs As String) As IEnumerable
        Dim consulta As IEnumerable
        Try
            consulta = From recursCercat In dc.Recurs
                       Where recursCercat.Nom.Contains(nomRecurs)
                       Select recursCercat
        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_GestorCursosBD_RetornaRecurs & ex.Message)

            consulta = Nothing
        End Try
        Return consulta
    End Function
End Class
