﻿Public Class Test
    Inherits System.Web.UI.Page
    Dim gestorCursos As GestorCursosBD = New GestorCursosBD()

    ''' <summary>
    ''' Carrega la llista de cursos tutoritzats per el tutor
    ''' </summary>
    ''' <remarks></remarks>
    Sub CarregaCursos()
        Try
            GridViewCursos.DataSource = gestorCursos.RetornaLlistaCursosTutor(UsuariActiu.idUsuari)
            GridViewCursos.DataBind()

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_PaginaTest_CarregaCursos & ex.Message, vbExclamation)
        End Try
    End Sub


    ''' <summary>
    ''' Comprova la compatibilitat de les dades d'una assignació
    ''' </summary>
    ''' <returns>0 si correcte , 1 altrament</returns>
    ''' <remarks></remarks>
    Function ComprovaDades() As Integer
        Dim resultat As Integer = 0

        If TextBoxIdCurs.Text = "" Then
            MsgBox(Resources.Missatges.Error_PaginaTest_ComprovaDades_IdCurs, vbInformation)
            resultat = 1
        End If
        If TextBoxIdTest.Text = "" Then
            MsgBox(Resources.Missatges.Error_PaginaTest_ComprovaDades_IdTest, vbInformation)
            resultat = 1
        End If

        Return resultat

    End Function

    ''' <summary>
    ''' Retorna els test cercats
    ''' </summary>
    ''' <remarks></remarks>
    Sub CarregaResultatCercaTest()
        Try
            If DropDownListCerca.Text = "Id" Then
                GridViewTest.DataSource = gestorCursos.RetornaTestId(TextBoxIdTest.Text)
            ElseIf DropDownListCerca.Text = "Nom" Then
                GridViewTest.DataSource = gestorCursos.RetornaTestNom(TextBoxNomTest.Text)
            End If

            GridViewTest.DataBind()

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_PaginaTest_CarregaResultatCerca & ex.Message, vbExclamation)
        End Try

    End Sub

    ''' <summary>
    '''  Carrega les dades del curs seleccionat
    ''' </summary>
    ''' <remarks></remarks>
    Sub SeleccionaCurs()
        Dim selectRow As GridViewRow = GridViewCursos.SelectedRow
        Try
            For Each curs In gestorCursos.RetornaCurs(selectRow.Cells(1).Text)
                TextBoxIdCurs.Text = curs.Id
                TextBoxNomCurs.Text = curs.Nom

            Next
            CarregaLlistaTestCurs()

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_PaginaTest_CarregaResultatCerca & ex.Message)
        End Try



    End Sub


    ''' <summary>
    ''' Carrega la llista dels test assignats al curs seleccionat
    ''' </summary>
    ''' <remarks></remarks>
    Sub CarregaLlistaTestCurs()
        Try
            Dim index As Integer = 1

            GridViewLlistaTestCurs.DataSource = gestorCursos.RetornaLlistaTestCurs(TextBoxIdCurs.Text)
            GridViewLlistaTestCurs.DataBind()
            GridViewLlistaTestCurs.Caption = "Llista dels test del curs " & TextBoxIdCurs.Text

        Catch ex As Exception
            MsgBox(Resources.Missatges.Error_PaginaAlumnesCurs_CarregaLlistaTestCurs & ex.Message, vbExclamation)

        End Try
    End Sub

    ''' <summary>
    '''  Carrega les dades del test seleccionat
    ''' </summary>
    ''' <remarks></remarks>
    Sub SeleccionaTest()
        Dim selectRow As GridViewRow = GridViewTest.SelectedRow

        For Each test In gestorCursos.RetornaTestId(selectRow.Cells(1).Text)
            TextBoxIdTest.Text = test.IdTest
            TextBoxNomTest.Text = test.Nom
        Next
        
    End Sub

  

    ''' <summary>
    ''' Assigna el test seleccionat al curs seleccionat
    ''' </summary>
    ''' <remarks></remarks>
    Sub AssignarTest()
        Try
            If gestorCursos.AssignaTest(TextBoxIdTest.Text, TextBoxIdCurs.Text) = 0 Then
                'èxit
                Utils.MostrarInformacioAccio(Resources.Missatges.Info_PaginaTest_AssignarTest_OK, LabelInfo, Timer1)
                CarregaLlistaTestCurs()
            Else
                Utils.MostrarInformacioAccio(Resources.Missatges.Info_PaginaTest_AssignarTest_KO, LabelInfo, Timer1)
            End If
        Catch ex As Exception
            MsgBox(ex.Message)
        End Try
    End Sub

    ''' <summary>
    ''' Desassigna el test seleccionat del curs seleccionat
    ''' </summary>
    ''' <remarks></remarks>
    Sub DesassignaTest()
        Try
            gestorCursos.EliminaAssignacioTest(TextBoxIdTest.Text, TextBoxIdCurs.Text)
            Utils.MostrarInformacioAccio(Resources.Missatges.Info_PaginaTest_DesassignaTest_OK, LabelInfo, Timer1)
            CarregaLlistaTestCurs()
        Catch ex As Exception
            Utils.MostrarInformacioAccio(Resources.Missatges.Info_PaginaTest_DesassignaTest_OK, LabelInfo, Timer1)

        End Try
    End Sub

    Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
        CarregaCursos()

    End Sub

    Protected Sub GridViewCursos_SelectedIndexChanged(sender As Object, e As EventArgs) Handles GridViewCursos.SelectedIndexChanged
        SeleccionaCurs()

    End Sub
    Protected Sub GridViewCursos_PageIndexChanging(ByVal sender As Object, ByVal e As GridViewPageEventArgs) Handles GridViewCursos.PageIndexChanging
        GridViewCursos.PageIndex = e.NewPageIndex
        CarregaCursos()
    End Sub


    Protected Sub Timer1_Tick(sender As Object, e As EventArgs) Handles Timer1.Tick
        LabelInfo.Visible = False
        Timer1.Enabled = False

    End Sub

    Protected Sub GridViewTest_SelectedIndexChanged(sender As Object, e As EventArgs) Handles GridViewTest.SelectedIndexChanged
        SeleccionaTest()

    End Sub

    Protected Sub ButtonCerca_Click(sender As Object, e As EventArgs) Handles ButtonCerca.Click
        CarregaResultatCercaTest()

    End Sub

    Protected Sub ButtonAfegir_Click(sender As Object, e As EventArgs) Handles ButtonAfegir.Click
        If ComprovaDades() = 0 Then AssignarTest()
    End Sub

    Protected Sub ButtonEsborra_Click(sender As Object, e As EventArgs) Handles ButtonEsborra.Click
        If ComprovaDades() = 0 Then DesassignaTest()

    End Sub

    Protected Sub GridViewLlistaTestCurs_SelectedIndexChanged(sender As Object, e As EventArgs) Handles GridViewLlistaTestCurs.SelectedIndexChanged

    End Sub
    Protected Sub GridViewLlistaTestCurs_PageIndexChanging(ByVal sender As Object, ByVal e As GridViewPageEventArgs) Handles GridViewLlistaTestCurs.PageIndexChanging
        GridViewLlistaTestCurs.PageIndex = e.NewPageIndex
        CarregaLlistaTestCurs()
    End Sub
End Class